Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1411)

Unified Diff: chrome/browser/ui/cocoa/exclusive_access_bubble_view.h

Issue 789403002: Rename fullscreen_exit_bubble_* to exclusive_access_bubble_* (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Updated based on CR comments Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/exclusive_access_bubble_view.h
diff --git a/chrome/browser/ui/cocoa/fullscreen_exit_bubble_view.h b/chrome/browser/ui/cocoa/exclusive_access_bubble_view.h
similarity index 38%
rename from chrome/browser/ui/cocoa/fullscreen_exit_bubble_view.h
rename to chrome/browser/ui/cocoa/exclusive_access_bubble_view.h
index c8e0f371c6c2d15b13f782947cf9aad463c11b2c..ef761b5b2bfdcf014f998065a8efbe0cb20f9594 100644
--- a/chrome/browser/ui/cocoa/fullscreen_exit_bubble_view.h
+++ b/chrome/browser/ui/cocoa/exclusive_access_bubble_view.h
@@ -2,13 +2,13 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_UI_COCOA_FULLSCREEN_EXIT_BUBBLE_VIEW_H_
-#define CHROME_BROWSER_UI_COCOA_FULLSCREEN_EXIT_BUBBLE_VIEW_H_
+#ifndef CHROME_BROWSER_UI_COCOA_EXCLUSIVE_ACCESS_BUBBLE_VIEW_H_
+#define CHROME_BROWSER_UI_COCOA_EXCLUSIVE_ACCESS_BUBBLE_VIEW_H_
#import <Cocoa/Cocoa.h>
-// A view that handles painting the background for the Fullscreen Exit Bubble.
-@interface FullscreenExitBubbleView : NSView
+// A view that handles painting the background for the Exclusive Access Bubble.
+@interface ExclusiveAccessBubbleView : NSView
@end
-#endif // CHROME_BROWSER_UI_COCOA_FULLSCREEN_EXIT_BUBBLE_VIEW_H_
+#endif // CHROME_BROWSER_UI_COCOA_EXCLUSIVE_ACCESS_BUBBLE_VIEW_H_
« no previous file with comments | « chrome/browser/ui/cocoa/browser_window_controller_private.mm ('k') | chrome/browser/ui/cocoa/exclusive_access_bubble_view.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698